# Sample Libre Office Output 1

## Effects

Sample text regular (no special effects): The quick brown fox jumps over the lazy dog

Sample text Upper Case: The quick brown fox jumps over the lazy dog

Sample Text gemeine (?): The quick brown fox jumps over the lazy dog

Sample text title: the quick brown fox jumps over the lazy dog

Sample text small caps: The quick brown fox jumps over the lazy dog

## Relief

Sample text embossed: The quick brown fox jumps over the lazy dog

Sample text engraved: The quick brown fox jumps over the lazy dog